# v0.1.0 (Thu Mar 05 2026)

:tada: This release contains work from new contributors! :tada:

Thanks for all your work!

:heart: Alyssa Dai ([@alyssadai](https://github.com/alyssadai))

:heart: Arman Jahanpour ([@rmanaem](https://github.com/rmanaem))

#### 🚀 Enhancements

- [ENH] Support specifying internal federation nodes in INI file [#10](https://github.com/neurobagel/configure-nb/pull/10) ([@alyssadai](https://github.com/alyssadai))
- [ENH] Add basic .ini to .env transformation functionality [#8](https://github.com/neurobagel/configure-nb/pull/8) ([@alyssadai](https://github.com/alyssadai) [@rmanaem](https://github.com/rmanaem))
- [ENH] Set up Typer app [#1](https://github.com/neurobagel/configure-nb/pull/1) ([@alyssadai](https://github.com/alyssadai))

#### 🏠 Internal

- [MNT] Complete packaging configuration for PyPI [#12](https://github.com/neurobagel/configure-nb/pull/12) ([@alyssadai](https://github.com/alyssadai))

#### ⚠️ Pushed to `main`

- Initial commit ([@alyssadai](https://github.com/alyssadai))

#### Authors: 2

- Alyssa Dai ([@alyssadai](https://github.com/alyssadai))
- Arman Jahanpour ([@rmanaem](https://github.com/rmanaem))
